# srenamer

srenamer is the simple renaming tool for TV shows and anime.

### Installation
It's recomended to install with [pipx](https://pipxproject.github.io/pipx/)
to not mess with default python installation.
```
$ pipx install srenamer
```
